@@ -25,13 +25,10 @@ from logicqubit.utils import *
 class LogicQuBit(Qubits, Gates, Circuit):
 
     def __init__(self, number_of_qubits = 3, **kwargs):
-        self.__cuda = kwargs.get('cuda', True)
-        self.__symbolic = kwargs.get('symbolic', False)
-        self.__first_left = kwargs.get('first_left', True)  # o qubit 1 é o mais a esquerda
-        if self.__symbolic:
-            self.__cuda = False
-        super().setCuda(self.__cuda)
-        super().setFirstLeft(self.__first_left)
+        symbolic = kwargs.get('symbolic', False)
+        first_left = kwargs.get('first_left', True)  # o qubit 1 é o mais a esquerda
+        super().setCuda(not symbolic)
+        super().setFirstLeft(first_left)
         super().setNumberOfQubits(number_of_qubits)
         Qubits.__init__(self)
         Gates.__init__(self, number_of_qubits)
@@ -205,7 +202,7 @@ class LogicQuBit(Qubits, Gates, Circuit):
 
     def get_shot(self, measured, shots):
         max_set = shots*100
-        if(self.__symbolic):
+        if not self.getCuda():
             list_all = [int(value * max_set) * [i] for i, value in enumerate(measured)]
         else:
             list_all = [int(value.real * max_set) * [i] for i, value in enumerate(measured)]
@@ -250,11 +247,11 @@ class LogicQuBit(Qubits, Gates, Circuit):
                     tlist[value-1] = super().P0()
                 else:
                     tlist[value-1] = super().P1()
-            if (not self.__first_left):
+            if not self.isFirstLeft():
                 tlist.reverse()
             M = self.kronProduct(tlist)
             measure = (density_m * M).get().trace()  # valor esperado
-            if(self.__cuda):
+            if self.getCuda():
                 measure = measure.get().item().real
             result.append(measure)
         self.setMeasuredValues(result)
@@ -283,7 +280,7 @@ class LogicQuBit(Qubits, Gates, Circuit):
         rho = self.DensityMatrix().get()
         for id1 in range(2**size_p):
             for id2 in range(2**size_p):
-                if (self.__cuda):
+                if self.getCuda():
                     value = rho[id1][id2]
                     if(not imaginary):
                         value = value.item().real
